=============
API reference
=============

.. module:: brreg

Exceptions
==========

.. autoclass:: BrregException
   :members:
   :undoc-members:


.. autoclass:: BrregRestException
   :members:
   :undoc-members:


Enhetsregisteret
================

.. automodule:: brreg.enhetsregisteret

.. autofunction:: brreg.enhetsregisteret.get_enhet

.. autoclass:: brreg.enhetsregisteret.Enhet
   :members:
   :undoc-members:

.. autoclass:: brreg.enhetsregisteret.Adresse
   :members:
   :undoc-members:

.. autoclass:: brreg.enhetsregisteret.InstitusjonellSektorkode
   :members:
   :undoc-members:

.. autoclass:: brreg.enhetsregisteret.Naeringskode
   :members:
   :undoc-members:

.. autoclass:: brreg.enhetsregisteret.Organisasjonsform
   :members:
   :undoc-members:
